# Code Quality Check

After completing a batch of code changes:

1. Run `make style` to auto-format the code
2. Run `make quality` to validate code quality
3. Fix any issues reported by `make quality`

When writing code, keep lines under 88 characters and avoid unnecessary indentation.
